@@ -3,9 +3,10 @@ to the network """
 
 
 __author__ = "Christian Staudt"
+__credits__ = ["Christian Staudt", "Elisabetta Bergamini", "Henning Meyerhenke", "Marc Nemes"]
 
 # extension imports
-from _NetworKit import Betweenness, PageRank, EigenvectorCentrality, DegreeCentrality, ApproxBetweenness, ApproxBetweenness2, DynBetweenness, DynApproxBetweenness
+from _NetworKit import Betweenness, PageRank, EigenvectorCentrality, DegreeCentrality, ApproxBetweenness, ApproxBetweenness2, DynApproxBetweenness, Closeness, KPathCentrality, CoreDecomposition, KatzCentrality, LocalClusteringCoefficient
 
 
 # local imports
@@ -61,6 +62,62 @@ def centralization(G, centralityMeasure):
 	return diff1 / diff2
 
 
+def rankPerNode(ranking):
+	"""
+	Parameters
+	----------
+ 	ranking: ordered list of tuples (node, score)
+
+	Returns
+	_______
+	for each node (sorted by node ID), the ranking of the node
+
+	"""
+	n_nodes = len(ranking)
+	ranking_id = [0]*n_nodes
+	for index, pair in enumerate(ranking):
+		ranking_id[pair[0]] = index
+	#we assign to all nodes the ranking of the first node with the same score
+	for index, pair in enumerate(ranking):
+			if index == 0:
+				continue
+			if pair[1] == ranking[index-1][1]:
+				prev_node = ranking[index-1][0]
+				ranking_id[pair[0]] = ranking_id[prev_node]
+	return ranking_id
+
+
+def relativeRankErrors(rx, ry):
+	"""
+	Let $r_x(u)$ be the rank of node $u$ in ranking $x$.
+	The relative rank error of node $u$ is defined as
+		$$r_x(u) / r_y(u)$$
+
+
+	Parameters
+	----------
+	rx : list
+		ranking - ordered list of tuples (node, score)
+
+	ry:  list
+		ranking - ordered list of tuples (node, score)
+
+	Returns
+	_______
+	list of rank errors ordered by node ID
+
+	"""
+	diff = []
+	n = len(rx)
+	if not(n == len(ry)):
+		return diff
+	rnode_x = rankPerNode(rx)
+	rnode_y = rankPerNode(ry)
+	for i in range(n):
+		diff.append((rnode_x[i]+1)/(rnode_y[i]+1))
+	return diff
+
+
 class SpectralCentrality:
 	"""
 	Abstract class to compute the spectral centrality of a graph. This class needs to be supplied with methods
@@ -73,7 +130,7 @@ class SpectralCentrality:
 		Parameters
 		----------
 		G : graph
-		    The graph of which to compute the centrality
+			The graph of which to compute the centrality
 		normalized : boolean
 					 Whether to normalize the results or not
 
@@ -111,6 +168,7 @@ class SpectralCentrality:
 
 		for v in self.graph.nodes():
 			self.evz[v] = self.eigenvector[v] * normFactor
+		return self
 
 	def scores(self):
 		if self.scoreList is None:
