@@ -86,6 +86,12 @@ public:
 	 */
 	virtual uint64_t size() const;
 
+
+	/**
+	 * @return current content of queue
+	 */
+	virtual std::set<std::pair<Key, Val>> content() const;
+
 	/**
 	 * Removes all elements from the PQ.
 	 */
@@ -173,6 +179,11 @@ inline uint64_t Aux::PrioQueue<Key, Val>::size() const {
 	return pqset.size();
 }
 
+template<class Key, class Val>
+inline std::set<std::pair<Key, Val>> Aux::PrioQueue<Key, Val>::content() const {
+	return pqset;
+}
+
 template<class Key, class Val>
 inline void Aux::PrioQueue<Key, Val>::clear() {
 	pqset.clear();
