@@ -10,10 +10,14 @@
 namespace NetworKit {
 
 
-Centrality::Centrality(const Graph& G, bool normalized) : G(G), normalized(normalized) {
+Centrality::Centrality(const Graph& G, bool normalized, bool computeEdgeCentrality) : Algorithm(), G(G), normalized(normalized), computeEdgeCentrality(computeEdgeCentrality) {
+	if (computeEdgeCentrality && !G.hasEdgeIds()) {
+		throw std::runtime_error("For edge centralities to be computed, edges must be indexed first: call G.indexEdges()");
+	}
 }
 
 double Centrality::score(node v) {
+	if (!hasRun) throw std::runtime_error("Call run method first");
 	return scoreData.at(v);
 }
 
@@ -26,11 +30,15 @@ std::vector<std::pair<node, double> > Centrality::ranking() {
 	return ranking;
 }
 
-
 std::vector<double> Centrality::scores() {
+	if (!hasRun) throw std::runtime_error("Call run method first");
 	return scoreData;
 }
 
+std::vector<double> Centrality::edgeScores() {
+	return edgeScoreData;
+}
+
 double Centrality::maximum() {
 	throw std::runtime_error("Not implemented: Compute the maximum centrality score in the respective centrality subclass.");
 }
