@@ -20,6 +20,13 @@ void EigenvectorCentrality::run() {
 	count z = G.upperNodeIdBound();
 	std::vector<double> values(z, 1.0);
 	scoreData = values;
+
+	// do not execute algorithm on directed graphs since this is error prone
+	// and can yield misleading results (wrong metric, not implementation fault!)
+	if (G.isDirected()) {
+		return;
+	}
+
 	double length = 0.0;
 	double oldLength = 0.0;
 
@@ -28,28 +35,40 @@ void EigenvectorCentrality::run() {
 		return (Aux::NumericTools::equal(val, other, tol));
 	});
 
-	// FIXME: What about self-loops in matrix?
 	do {
 		oldLength = length;
 
 		// iterate matrix-vector product
 		G.parallelForNodes([&](node u) {
+			values[u] = 0.0;
 			G.forNeighborsOf(u, [&](node v) {
 				values[u] += G.weight(u, v) * scoreData[v];
 			});
 		});
 
+//		// set everything very small to zero
+//		G.parallelForNodes([&](node u) {
+//			if (values[u] < 1e-16) {
+//				values[u] = 0.0;
+//			}
+//		});
+
 		// normalize values
 		length = 0.0;
 		length = G.parallelSumForNodes([&](node u) {
 			return (values[u] * values[u]);
 		});
 		length = sqrt(length);
+
+//		TRACE("length: ", length);
+//		TRACE(values);
+
+		assert(! Aux::NumericTools::equal(length, 1e-16));
 		G.parallelForNodes([&](node u) {
 			values[u] /= length;
 		});
 
-//		TRACE("length: ", length);
+//		TRACE(values);
 
 		scoreData = values;
 	} while (! converged(length, oldLength));
@@ -60,6 +79,8 @@ void EigenvectorCentrality::run() {
 			scoreData[u] = fabs(scoreData[u]);
 		});
 	}
+
+	hasRun = true;
 }
 
 } /* namespace NetworKit */
