@@ -7,6 +7,7 @@
 
 #include "PageRank.h"
 #include "../auxiliary/NumericTools.h"
+#include "../auxiliary/SignalHandling.h"
 
 namespace NetworKit {
 
@@ -17,6 +18,7 @@ NetworKit::PageRank::PageRank(const Graph& G, double damp, double tol):
 }
 
 void NetworKit::PageRank::run() {
+	Aux::SignalHandler handler;
 	count n = G.numberOfNodes();
 	count z = G.upperNodeIdBound();
 	double oneOverN = 1.0 / (double) n;
@@ -25,11 +27,17 @@ void NetworKit::PageRank::run() {
 	std::vector<double> pr = scoreData;
 	bool isConverged = false;
 
+	std::vector<double> deg(z, 0.0);
+	G.parallelForNodes([&](node u) {
+		deg[u] = (double) G.weightedDegree(u);
+	});
+
 	while (! isConverged) {
+		handler.assureRunning();
 		G.balancedParallelForNodes([&](node u) {
 			pr[u] = 0.0;
-			G.forNeighborsOf(u, [&](node v) {
-				pr[u] += scoreData[v] * G.weight(u, v) / (double) G.weightedDegree(v);
+			G.forInEdgesOf(u, [&](node u, node v) {
+				pr[u] += scoreData[v] * G.weight(v, u) / deg[v];
 			});
 			pr[u] *= damp;
 			pr[u] += teleportProb;
@@ -40,13 +48,14 @@ void NetworKit::PageRank::run() {
 				double d = scoreData[u] - pr[u];
 				return d * d;
 			});
+//			TRACE("sqrt(diff): ", sqrt(diff));
 			return (sqrt(diff) <= tol);
 		});
 
 		isConverged = converged();
 		scoreData = pr;
 	}
-
+	handler.assureRunning();
 	// make sure scoreData sums up to 1
 	double sum = G.parallelSumForNodes([&](node u) {
 		return scoreData[u];
@@ -55,6 +64,8 @@ void NetworKit::PageRank::run() {
 	G.parallelForNodes([&](node u) {
 		scoreData[u] /= sum;
 	});
+
+	hasRun = true;
 }
 
 } /* namespace NetworKit */
