@@ -34,6 +34,9 @@ protected:
 
 	std::unique_ptr<Overlapper> overlap; //!< clustering overlap algorithm
 
+	Partition core;
+	std::vector<Partition> baseClusterings;
+
 public:
 	/**
 	 * Constructor to the EPP community detection algorithm.
@@ -75,6 +78,11 @@ public:
 	 */
 	virtual std::string toString() const;
 
+
+	std::vector<Partition> getBasePartitions() const;
+
+	Partition getCorePartition() const;
+
 };
 
 } /* namespace NetworKit */
