@@ -18,7 +18,7 @@ namespace NetworKit {
 /**
  * @ingroup distmeasures
  * Algebraic distance assigns a distance value to pairs of nodes
- * according to their structural closeness in the graph. 
+ * according to their structural closeness in the graph.
  */
 class AlgebraicDistance: public NetworKit::NodeDistance {
 public:
@@ -48,6 +48,12 @@ public:
 	 */
 	 virtual double distance(node u, node v);
 
+
+	/**
+	* @return A value for each node and each system.
+	*/
+	std::vector<std::vector<double> > getLoadsOnNodes();
+
 protected:
 
 	count numSystems; //!< number of vectors/systems used for algebraic iteration
