@@ -18,8 +18,12 @@ void GraphUpdater::update(std::vector<GraphEvent>& stream) {
 		TRACE("event: " , ev.toString());
 		switch (ev.type) {
 			case GraphEvent::NODE_ADDITION : {
+#if (LOG_LEVEL == LOG_LEVEL_TRACE)
 				node u = G.addNode();
 				TRACE("added node " , u, ", ev.u: ", ev.u);
+#else
+				G.addNode();
+#endif
 				assert (u == ev.u);
 				break;
 			}
