@@ -70,7 +70,7 @@ void DynBFS::update(const std::vector<GraphEvent>& batch) {
 				previous[w].clear();
 			}
 			npaths[w] = 0;
-			G.forNeighborsOf(w, [&](node z) {
+			G.forInNeighborsOf(w, [&](node w, node z) {
 				//z is a predecessor for w
 				if (distances[w] == distances[z]+1) {
 					if (storePreds) {
