@@ -70,7 +70,7 @@ void DynDijkstra::update(const std::vector<GraphEvent>& batch) {
 			previous[current].clear();
 		}
 		npaths[current] = 0;
-		G.forNeighborsOf(current, [&](node z, edgeweight w){
+		G.forInNeighborsOf(current, [&](node current, node z, edgeweight w){
 			//z is a predecessor of current node
 			if (Aux::NumericTools::equal(distances[current], distances[z]+w, 0.000001)) {
 				if (storePreds) {
