@@ -9,7 +9,7 @@
 
 namespace NetworKit {
 
-EdgeListPartitionReader::EdgeListPartitionReader(node firstNode) : firstNode(firstNode) {
+EdgeListPartitionReader::EdgeListPartitionReader(node firstNode, char sepChar) : firstNode(firstNode), sepChar(sepChar) {
 }
 
 Partition EdgeListPartitionReader::read(std::string path) {
@@ -24,7 +24,7 @@ Partition EdgeListPartitionReader::read(std::string path) {
 	index newOmega = 0;
 	Partition zeta(0); // start without nodes
 	while(std::getline(file, line)) {
-		std::vector<std::string> split = Aux::StringTools::split(line, '\t');
+		std::vector<std::string> split = Aux::StringTools::split(line, sepChar);
 		if (split.size() == 2 && split[0] != "#") {
 			index c = std::atoi(split[1].c_str());
 			// NetworKit uses zero-based node ids, adapt input accordingly
