@@ -133,7 +133,7 @@ std::vector<index> Partition::getVector() const {
 }
 
 
-std::set<std::set<index> > Partition::getSubsets() {
+std::set<std::set<index> > Partition::getSubsets() const {
 	std::vector<std::set<index> > table(omega+1);
 	this->forEntries([&](index e, index s){
 		assert(s <= omega);
