@@ -1,8 +1,9 @@
 # NetworKit native classes and functions
-from _NetworKit import GraphProperties, ConnectedComponents, ParallelConnectedComponents, StronglyConnectedComponents, ClusteringCoefficient, Diameter, Eccentricity, CoreDecomposition
+from _NetworKit import GraphProperties, ConnectedComponents, ParallelConnectedComponents, StronglyConnectedComponents, ClusteringCoefficient, Diameter, Eccentricity, EffectiveDiameter
 
 # other submodules
 from . import community
+from . import centrality
 from . import termgraph
 from . import auxiliary
 from . import nxadapter
@@ -42,8 +43,11 @@ def size(G):
 
 def degrees(G):
 	""" Return min/max/avg degree"""
-	minMaxDeg = GraphProperties.minMaxDegree(G)
 	avgDeg = GraphProperties.averageDegree(G)
+	if G.isDirected():
+		minMaxDeg = GraphProperties.minMaxDegreeDirected(G)
+	else:
+		minMaxDeg = GraphProperties.minMaxDegree(G)
 	return (minMaxDeg[0], minMaxDeg[1], avgDeg)
 
 def degreeDistribution(G):
@@ -59,7 +63,11 @@ def degreeSequence(G):
 def density(G):
 	""" Return the density of the graph"""
 	(n, m) = size(G)
-	return (2 * m) / (n * (n-1))
+	if G.isDirected():
+		d = m / (n * (n-1))
+	else:
+		d = (2 * m) / (n * (n-1))
+	return d
 
 def components(G):
 	""" Find and analyze detected components.
@@ -95,9 +103,12 @@ def clustering(G, error=0.01):
 		for details see:
 			Schank, Wagner: Approximating Clustering Coefficient and Transitivity
 	"""
-	nSamples = math.ceil(math.log(10) / (error**2)) # fixed confidence of 90%
-	logging.info("taking {0} samples".format(nSamples))
-	return ClusteringCoefficient().approxAvgLocal(G, nSamples)
+	if G.numberOfNodes() < 100:
+		return ClusteringCoefficient().avgLocal(G)
+	else:
+		nSamples = math.ceil(math.log(10) / (error**2)) # fixed confidence of 90%
+		logging.info("taking {0} samples".format(nSamples))
+		return ClusteringCoefficient().approxAvgLocal(G, nSamples)
 
 
 def degreePowerLaw(G, dd=None):
@@ -110,7 +121,8 @@ def degreePowerLaw(G, dd=None):
 	R : double
 		goodness of the fit, i.e.
 		the loglikelihood ratio between the two candidate distributions. This number will be positive if the data is more likely in the first distribution, and negative if the data is more likely in the 		  	 	second distribution. The exponential distribution is the absolute minimum alternative candidate for evaluating the heavy- tailedness of the distribution. The reason is definitional: the typical quantitative definition of a ”heavy- tail” is that it is not exponentially bounded. Thus if a power law is not a better fit than an exponential distribution (as in the above example) there is scarce ground for considering the distribution to be heavy-tailed at all, let alone a power law.
-
+	gamma : double
+		the degree power law exponent
 	"""
 	if not dd:
 		dd = degreeSequence(G)
@@ -135,18 +147,28 @@ def degreePowerLaw(G, dd=None):
 
 def degreeAssortativity(G):
 	""" Returns the degree assortativity coefficient """
-	return GraphProperties.degreeAssortativity(G, G.isWeighted())
+	if G.isDirected():
+		results = []
+		results.append(GraphProperties.degreeAssortativityDirected(G,0,0))
+		results.append(GraphProperties.degreeAssortativityDirected(G,1,1))
+		return results
+	else:
+		return GraphProperties.degreeAssortativity(G, G.isWeighted())
 
 
 def degeneracy(G):
 	""" degeneracy of an undirected graph is defined as the largest k for which
 	the graph has a non-empty k-core"""
-	coreDec = CoreDecomposition(G)
+	coreDec = centrality.CoreDecomposition(G)
 	coreDec.run()
 	return coreDec.maxCoreNumber()
 
 
 def properties(G, settings):
+	"""
+	Helper function for the properties.overview function.
+	Calculates a number of network properties.
+	"""
 	logging.info("[...] calculating properties")
 
 	# size
@@ -176,7 +198,7 @@ def properties(G, settings):
 
 	ncomPLP, modPLP = None, None
 	ncomPLM, modPLM = None, None
-	if settings["communities"]:
+	if settings["communities"] and not G.isDirected():
 		logging.info("[...] detecting communities")
 		# perform PLM community detection
 		logging.info("[...] performing community detection: PLM")
@@ -203,15 +225,22 @@ def properties(G, settings):
 	# diameter
 	if settings["diameter"]:
 		logging.info("[...] estimating diameter range")
-		dia = Diameter.estimatedDiameterRange(G, error=0.1)
+		try:
+			dia = Diameter.estimatedDiameterRange(G, error=0.1)
+		except Exception as e:
+			print(e)
+			dia = "Not implemented for directed graphs"
 	else:
-		dia = None
+		dia = "Not selected"
 
 	# clustering
 	avglcc = None
 	if settings["clustering"]:
 		logging.info("[...] approximating clustering coefficient")
-		avglcc = clustering(G)
+		if not G.isDirected():
+			avglcc = clustering(G)
+		else:
+			avglcc = None
 
 	# degree assortativity
 	logging.info("[...] calculating degree assortativity coefficient")
@@ -262,17 +291,17 @@ def overview(G, settings=collections.defaultdict(lambda: True), showDegreeHistog
 		["isolated nodes", props["isolates"]],
 		["self-loops", props["loops"]],
 		["density", "{0:.6f}".format(props["dens"]) if props["dens"] else None],
-		["clustering coefficient", "{0:.6f}".format(props["avglcc"]) if props["avglcc"] else None],
+		["clustering coefficient", "Not implemented for directed graphs" if not props["avglcc"] else "{0:.6f}".format(props["avglcc"])],
 		["max. core number", props["degeneracy"]],
-		["connected components", props["nComponents"]],
+		["{0}connected components".format("strongly " if G.isDirected() else None), props["nComponents"]],
 		["size of largest component", "{0} ({1:.2f} %)".format(props["sizeLargestComponent"], (props["sizeLargestComponent"] / props["n"]) * 100)],
 		["estimated diameter range", str(props["dia"])],
 	]
 	degreeProperties = [
-		["min./max. degree", "({0}, {1})".format(props["minDeg"], props["maxDeg"])],
-		["avg. degree", "{0:.6f}".format(props["avgDeg"])],
+		["min./max. degree{0}".format(" (in,out)" if G.isDirected() else ""), "({0} / {1})".format(props["minDeg"], props["maxDeg"])],
+		["avg. degree",	"{0:.6f}".format(props["avgDeg"])],
 		["power law?, likelihood, gamma", "{0}, {1}, {2}".format(props["plfit"][0], "{0:.4f}".format(props["plfit"][1]), "{0:.4f}".format(props["plfit"][2]))],
-		["degree assortativity", "{0:.4f}".format(props["assort"])],
+		["degree assortativity{0}".format(" (in,in),(out,out)" if G.isDirected() else ""), "{0:.4f}".format(props["assort"]) if not G.isDirected() else ", ".join(["{0:.4f}".format(x) for x in props["assort"]]) ],
 	]
 
 	communityStructure = [
@@ -290,10 +319,14 @@ def overview(G, settings=collections.defaultdict(lambda: True), showDegreeHistog
 	print(tabulate.tabulate(degreeProperties))
 	#print("Miscellaneous")
 	#print(tabulate.tabulate(miscProperties))
-	print("Community Structure")
-	print(tabulate.tabulate(communityStructure))
+	if not G.isDirected():
+		print("Community Structure")
+		print(tabulate.tabulate(communityStructure))
 	if showDegreeHistogram:
-		print("Degree Distribution")
+		if G.isDirected():
+			print("Degree Distribution (in+out)")
+		else:
+			print("Degree Distribution")
 		print("-------------------")
 		(labels, histo) = props["histo"]
 		if labels and histo:
